summaryrefslogtreecommitdiffstats
path: root/examples
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2010-03-25 12:49:23 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2010-03-25 12:49:23 (GMT)
commit49826ea52c056858a0ec1aac6188dcbce15b7798 (patch)
treedd162f823379e3d49f28806a2ee60149b34a78d0 /examples
parentd0c4c5741e4c29e4dc9e67062e2692d6316e2056 (diff)
downloadhdf5-49826ea52c056858a0ec1aac6188dcbce15b7798.zip
hdf5-49826ea52c056858a0ec1aac6188dcbce15b7798.tar.gz
hdf5-49826ea52c056858a0ec1aac6188dcbce15b7798.tar.bz2
[svn-r18452] Description:
Finish renaming cache-related files & symbols on metadata journaling branch. Metadata cache-related symbols/files with no suffix now have a '1' suffix and symbols/files with a '2' suffix now have no suffix. Tested on: Mac OS X/32 10.6.2 (amazon) w/debug, prod & parallel (h5committest not required on this branch)
Diffstat (limited to 'examples')
-rw-r--r--examples/mdj_api_example.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/examples/mdj_api_example.c b/examples/mdj_api_example.c
index c798df3..0931be8 100644
--- a/examples/mdj_api_example.c
+++ b/examples/mdj_api_example.c
@@ -56,7 +56,7 @@
* use H5Pset_jnl_config() to replace the default journaling
* configuration with our own. See the comments in the code
* for the particulars -- note that we must set the version
* field of the H5AC2_jnl_config_t struct before calling
* H5Pget_jnl_config().
*
* After setting up the FAPL, we create the file as usual.
@@ -75,11 +75,11 @@
* and re-enable it via H5Fget_jnl_config() and H5Fset_jnl_config()
* calls. Note that when we re-enable journaling via the
* H5Fset_jnl_config() call, we don't need to set all the fields
* in the H5AC2_jnl_config_t struct again; we are simply re-using
* the configuration obtained via the H5Fget_jnl_config() call.
* (If we had originally opened the file without journaling and
* then wanted to enable journaling, we would have to set up the
* fields of the H5AC2_jnl_config_t struct in much the same way
* we did earlier in this example. We would also have had to
* use H5Pset_libver_bounds() to set the FAPL to create the file
* initially with the latest HDF5 file format format.)
@@ -159,8 +159,8 @@ mdj_api_example(char * hdf5_file_name,
hsize_t offset[2];
hsize_t chunk_size[2];
int data_chunk[CHUNK_SIZE][CHUNK_SIZE];
- H5AC2_jnl_config_t jnl_config_0;
- H5AC2_jnl_config_t jnl_config_1;
+ H5AC_jnl_config_t jnl_config_0;
+ H5AC_jnl_config_t jnl_config_1;
fprintf(stdout, "running journaling example -- this may take a while:\n");
fflush(stdout);
@@ -172,7 +172,7 @@ mdj_api_example(char * hdf5_file_name,
}
if ( ( jnl_file_name == NULL ) ||
- ( strlen(jnl_file_name) > H5AC2__MAX_JOURNAL_FILE_NAME_LEN ) )
+ ( strlen(jnl_file_name) > H5AC__MAX_JOURNAL_FILE_NAME_LEN ) )
{
fprintf(stderr, "bad journal file name. Exiting...\n");
exit(1);
@@ -213,7 +213,7 @@ mdj_api_example(char * hdf5_file_name,
* illustrated here shows off the H5Pget_jnl_config() call and is less
* susceptible to API definition changes.
*/
- jnl_config_0.version = H5AC2__CURR_JNL_CONFIG_VER;
+ jnl_config_0.version = H5AC__CURR_JNL_CONFIG_VER;
status = H5Pget_jnl_config(fapl_id, &jnl_config_0);
@@ -359,7 +359,7 @@ mdj_api_example(char * hdf5_file_name,
* journaling will also cause HDF5 to close and discard the
* journal file after all metadata is on disk.
*/
- jnl_config_1.version = H5AC2__CURR_JNL_CONFIG_VER;
+ jnl_config_1.version = H5AC__CURR_JNL_CONFIG_VER;
status = H5Fget_jnl_config(file_id, &jnl_config_1);
@@ -56,7 +56,7 @@
* configuration with our own. See the comments in the code
* for the particulars -- note that we must set the version
- * field of the H5AC2_jnl_config_t struct before calling
+ * field of the H5AC_jnl_config_t struct before calling
* H5Pget_jnl_config().
*
@@ -75,11 +75,11 @@
* calls. Note that when we re-enable journaling via the
* H5Fset_jnl_config() call, we don't need to set all the fields
- * in the H5AC2_jnl_config_t struct again; we are simply re-using
+ * in the H5AC_jnl_config_t struct again; we are simply re-using
* the configuration obtained via the H5Fget_jnl_config() call.
* (If we had originally opened the file without journaling and
@@ -75,11 +75,11 @@
* (If we had originally opened the file without journaling and
* then wanted to enable journaling, we would have to set up the
- * fields of the H5AC2_jnl_config_t struct in much the same way
+ * fields of the H5AC_jnl_config_t struct in much the same way
* we did earlier in this example. We would also have had to
* use H5Pset_libver_bounds() to set the FAPL to create the file